# SwaggerClient-php
App/Webpage optimized weather data for latitude/longitude points, ZIP/Postal Codes, and OnPoint™ points. The Weather Source App Weather API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate use. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  This API returns current conditions (Nowcast) and a 7-day of daily and hourly forecast. The nowcast and forecasts include limited astronomical data.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.      **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

This PHP package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Build package: io.swagger.codegen.v3.generators.php.PhpClientCodegen
For more information, please visit [https://developer.weathersourceapis.com/](https://developer.weathersourceapis.com/)

## Requirements

PHP 5.5 and later

## Installation & Usage
### Composer

To install the bindings via [Composer](http://getcomposer.org/), add the following to `composer.json`:

```
{
  "repositories": [
    {
      "type": "git",
      "url": "https://github.com/GIT_USER_ID/GIT_REPO_ID.git"
    }
  ],
  "require": {
    "GIT_USER_ID/GIT_REPO_ID": "*@dev"
  }
}
```

Then run `composer install`

### Manual Installation

Download the files and include `autoload.php`:

```php
    require_once('/path/to/SwaggerClient-php/vendor/autoload.php');
```

## Tests

To run the unit tests:

```
composer install
./vendor/bin/phpunit
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\OnpointsApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$onpoint_id = 56; // int | An OnPoint™ ID.
$services = array("services_example"); // string[] | A comma separated list of service names to return.  **Limiting the query to needed services will improve the query response time.**
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>
$language = "ENGLISH"; // string | The language for translatable returned values.<br>

try {
    $result = $apiInstance->onpointsOnpointIdGet($onpoint_id, $services, $fields, $unit_scale, $language);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling OnpointsApi->onpointsOnpointIdGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

## Documentation for API Endpoints

All URIs are relative to *https://appwx.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OnpointsApi* | [**onpointsOnpointIdGet**](docs/Api/OnpointsApi.md#onpointsonpointidget) | **GET** /onpoints/{onpointId} | App Weather for an OnPoint™ point.
*PointsApi* | [**pointsLatitudelongitudeGet**](docs/Api/PointsApi.md#pointslatitudelongitudeget) | **GET** /points/{latitude},{longitude} | App Weather for a Latitude/Longitude point.
*PostcodesApi* | [**postcodesPostcodecountryCodeGet**](docs/Api/PostcodesApi.md#postcodespostcodecountrycodeget) | **GET** /postcodes/{postcode},{countryCode} | App Weather response for a postcode.

## Documentation For Models

 - [AppwxOnpointObj](docs/Model/AppwxOnpointObj.md)
 - [AppwxPointObj](docs/Model/AppwxPointObj.md)
 - [AppwxPostcodeObj](docs/Model/AppwxPostcodeObj.md)
 - [BoundingPoints](docs/Model/BoundingPoints.md)
 - [BoundingPointsInner](docs/Model/BoundingPointsInner.md)
 - [CivilRise](docs/Model/CivilRise.md)
 - [CivilSet](docs/Model/CivilSet.md)
 - [CldCvr](docs/Model/CldCvr.md)
 - [CldCvrMax](docs/Model/CldCvrMax.md)
 - [CldCvrMin](docs/Model/CldCvrMin.md)
 - [CountryCode](docs/Model/CountryCode.md)
 - [CountryName](docs/Model/CountryName.md)
 - [Date](docs/Model/Date.md)
 - [Distance](docs/Model/Distance.md)
 - [Elevation](docs/Model/Elevation.md)
 - [ErrorObj](docs/Model/ErrorObj.md)
 - [FeaturesObj](docs/Model/FeaturesObj.md)
 - [FeelsLike](docs/Model/FeelsLike.md)
 - [FeelsLikeMax](docs/Model/FeelsLikeMax.md)
 - [FeelsLikeMin](docs/Model/FeelsLikeMin.md)
 - [FieldListObj](docs/Model/FieldListObj.md)
 - [Fields](docs/Model/Fields.md)
 - [ForecastDayArr](docs/Model/ForecastDayArr.md)
 - [ForecastDayObj](docs/Model/ForecastDayObj.md)
 - [ForecastHourArr](docs/Model/ForecastHourArr.md)
 - [ForecastHourObj](docs/Model/ForecastHourObj.md)
 - [Grid](docs/Model/Grid.md)
 - [Icon](docs/Model/Icon.md)
 - [Language](docs/Model/Language.md)
 - [Latitude](docs/Model/Latitude.md)
 - [Longitude](docs/Model/Longitude.md)
 - [MoonPhase](docs/Model/MoonPhase.md)
 - [NowcastObj](docs/Model/NowcastObj.md)
 - [OnpointId](docs/Model/OnpointId.md)
 - [OnpointObj](docs/Model/OnpointObj.md)
 - [PointObj](docs/Model/PointObj.md)
 - [Postcode](docs/Model/Postcode.md)
 - [PostcodeObj](docs/Model/PostcodeObj.md)
 - [Precip](docs/Model/Precip.md)
 - [PrecipFlag](docs/Model/PrecipFlag.md)
 - [PrecipIntensity](docs/Model/PrecipIntensity.md)
 - [PrecipProb](docs/Model/PrecipProb.md)
 - [RelHum](docs/Model/RelHum.md)
 - [RelHumMax](docs/Model/RelHumMax.md)
 - [RelHumMin](docs/Model/RelHumMin.md)
 - [Snowfall](docs/Model/Snowfall.md)
 - [SnowfallFlag](docs/Model/SnowfallFlag.md)
 - [SnowfallIntensity](docs/Model/SnowfallIntensity.md)
 - [SnowfallProb](docs/Model/SnowfallProb.md)
 - [SubdivCode](docs/Model/SubdivCode.md)
 - [SubdivName](docs/Model/SubdivName.md)
 - [Summary](docs/Model/Summary.md)
 - [SummaryLong](docs/Model/SummaryLong.md)
 - [SunTransit](docs/Model/SunTransit.md)
 - [Sunrise](docs/Model/Sunrise.md)
 - [Sunset](docs/Model/Sunset.md)
 - [Temp](docs/Model/Temp.md)
 - [TempMax](docs/Model/TempMax.md)
 - [TempMin](docs/Model/TempMin.md)
 - [Timestamp](docs/Model/Timestamp.md)
 - [Timezone](docs/Model/Timezone.md)
 - [UnitScale](docs/Model/UnitScale.md)
 - [WindDir](docs/Model/WindDir.md)
 - [WindDirAvg](docs/Model/WindDirAvg.md)
 - [WindSpd](docs/Model/WindSpd.md)
 - [WindSpdMax](docs/Model/WindSpdMax.md)
 - [WindSpdMin](docs/Model/WindSpdMin.md)

## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

support@weathersource.com

